@@ -1,3 +1,5 @@
+# rubocop:disable Naming/FileName
+
 # encoding: utf-8
 
 require 'set'
@@ -7,10 +9,12 @@ require 'puppet-lint/lexer'
 require 'puppet-lint/configuration'
 require 'puppet-lint/data'
 require 'puppet-lint/checks'
+require 'puppet-lint/report/github'
 require 'puppet-lint/bin'
 require 'puppet-lint/monkeypatches'
 
 class PuppetLint::NoCodeError < StandardError; end
+
 class PuppetLint::NoFix < StandardError; end
 
 # Parser Syntax Errors
@@ -19,6 +23,7 @@ class PuppetLint::SyntaxError < StandardError
 
   def initialize(token)
     @token = token
+    super
   end
 end
 
@@ -58,7 +63,7 @@ class PuppetLint
   # Public: Initialise a new PuppetLint object.
   def initialize
     @code = nil
-    @statistics = { :error => 0, :warning => 0, :fixed => 0, :ignored => 0 }
+    @statistics = { error: 0, warning: 0, fixed: 0, ignored: 0 }
     @manifest = ''
   end
 
@@ -100,9 +105,9 @@ class PuppetLint
   # Returns a format String to be used with String#%.
   def log_format
     if configuration.log_format.nil? || configuration.log_format.empty?
-      ## recreate previous old log format as far as thats possible.
       format = '%{KIND}: %{message} on line %{line}'
       format.prepend('%{path} - ') if configuration.with_filename
+      format.concat(' (check: %{check})')
       configuration.log_format = format
     end
 
@@ -121,6 +126,16 @@ class PuppetLint
     puts "  #{message[:reason]}" if message[:kind] == :ignored && !message[:reason].nil?
   end
 
+  # Internal: Format a problem message and print it to STDOUT so GitHub Actions
+  # recognizes it as an annotation.
+  #
+  # message - A Hash containing all the information about a problem.
+  #
+  # Returns nothing.
+  def print_github_annotation(message)
+    puts PuppetLint::Report::GitHubActionsReporter.format_problem(path, message)
+  end
+
   # Internal: Get the line of the manifest on which the problem was found
   #
   # message - A Hash containing all the information about a problem.
@@ -150,7 +165,7 @@ class PuppetLint
   # problems - An Array of problem Hashes as returned by
   #            PuppetLint::Checks#run.
   #
-  # Returns nothing.
+  # Returns array of problem.
   def report(problems)
     json = []
     problems.each do |message|
@@ -158,19 +173,19 @@ class PuppetLint
 
       message[:KIND] = message[:kind].to_s.upcase
 
-      if message[:kind] == :fixed || [message[:kind], :all].include?(configuration.error_level)
-        if configuration.json
-          message['context'] = get_context(message) if configuration.with_context
-          json << message
-        else
-          format_message(message)
-          print_context(message) if configuration.with_context
-        end
+      next unless message[:kind] == :fixed || [message[:kind], :all].include?(configuration.error_level)
+
+      if configuration.json || configuration.sarif
+        message['context'] = get_context(message) if configuration.with_context
+        json << message
+      else
+        format_message(message)
+        print_context(message) if configuration.with_context
+        print_github_annotation(message) if configuration.github_actions
       end
     end
-    puts JSON.pretty_generate(json) if configuration.json
-
     $stderr.puts 'Try running `puppet parser validate <file>`' if problems.any? { |p| p[:check] == :syntax }
+    json
   end
 
   # Public: Determine if PuppetLint found any errors in the manifest.
