@@ -21,11 +21,11 @@ class PuppetLint::CheckPlugin
     check
 
     @problems.each do |problem|
-      if PuppetLint::Data.ignore_overrides[problem[:check]].has_key?(problem[:line])
-        problem[:kind] = :ignored
-        problem[:reason] = PuppetLint::Data.ignore_overrides[problem[:check]][problem[:line]]
-        next
-      end
+      next if problem[:check] == :syntax
+      next unless PuppetLint::Data.ignore_overrides[problem[:check]].key?(problem[:line])
+
+      problem[:kind] = :ignored
+      problem[:reason] = PuppetLint::Data.ignore_overrides[problem[:check]][problem[:line]]
     end
 
     @problems
@@ -35,15 +35,14 @@ class PuppetLint::CheckPlugin
   #
   # Returns an Array of problem Hashes.
   def fix_problems
-    @problems.reject { |problem| problem[:kind] == :ignored }.each do |problem|
-      if self.respond_to?(:fix)
-        begin
-          fix(problem)
-        rescue PuppetLint::NoFix
-          # noop
-        else
-          problem[:kind] = :fixed
-        end
+    @problems.reject { |problem| problem[:kind] == :ignored || problem[:check] == :syntax }.each do |problem|
+      next unless respond_to?(:fix)
+
+      begin
+        fix(problem)
+        problem[:kind] = :fixed
+      rescue PuppetLint::NoFix
+        # noop
       end
     end
 
@@ -59,6 +58,14 @@ class PuppetLint::CheckPlugin
     PuppetLint::Data.tokens
   end
 
+  def add_token(index, token)
+    PuppetLint::Data.insert(index, token)
+  end
+
+  def remove_token(token)
+    PuppetLint::Data.delete(token)
+  end
+
   # Public: Provides the resource titles to the check plugins.
   #
   # Returns an Array of PuppetLint::Lexer::Token objects.
@@ -98,6 +105,38 @@ class PuppetLint::CheckPlugin
     PuppetLint::Data.node_indexes
   end
 
+  # Public: Provides positional information for any array definitions in the
+  # tokens array to the check plugins.
+  #
+  # Returns an array of hashes containing the position information.
+  def array_indexes
+    PuppetLint::Data.array_indexes
+  end
+
+  # Public: Provides positional information for any hash definitions in the
+  # tokens array to the check plugins.
+  #
+  # Returns an array of hashes containing the position information.
+  def hash_indexes
+    PuppetLint::Data.hash_indexes
+  end
+
+  # Public: Provides positional information for any default definitions in the
+  # tokens array to the check plugins.
+  #
+  # Returns an Array of Hashes containing the position information.
+  def defaults_indexes
+    PuppetLint::Data.defaults_indexes
+  end
+
+  # Public: Provides positional information for any function definition in the
+  # tokens array to the check plugins.
+  #
+  # Returns an Array of Hashes containing the position information.
+  def function_indexes
+    PuppetLint::Data.function_indexes
+  end
+
   # Public: Provides the expanded path of the file being analysed to check
   # plugins.
   #
@@ -140,10 +179,10 @@ class PuppetLint::CheckPlugin
   # Returns a Hash of default problem information.
   def default_info
     @default_info ||= {
-      :check      => self.class.const_get('NAME'),
-      :fullpath   => fullpath,
-      :path       => path,
-      :filename   => filename,
+      check: self.class.const_get('NAME'),
+      fullpath: fullpath,
+      path: path,
+      filename: filename,
     }
   end
 
@@ -151,22 +190,24 @@ class PuppetLint::CheckPlugin
   #
   # kind    - The Symbol problem type (:warning or :error).
   # problem - A Hash containing the attributes of the problem
-  #   :message - The String message describing the problem.
-  #   :line    - The Integer line number of the location of the problem.
-  #   :column  - The Integer column number of the location of the problem.
-  #   :check   - The Symbol name of the check that detected the problem.
+  #   :message      - The String message describing the problem.
+  #   :line         - The Integer line number of the location of the problem.
+  #   :column       - The Integer column number of the location of the problem.
+  #   :check        - The Symbol name of the check that detected the problem.
+  #   :description  - The description of the check that detected the problem.
+  #   :help_uri     - The help web page of the check that detected the problem.
   #
   # Returns nothing.
   def notify(kind, problem)
     problem[:kind] = kind
-    problem.merge!(default_info) { |key, v1, v2| v1 }
+    problem.merge!(default_info) { |_key, v1, _v2| v1 }
 
-    unless [:warning, :error, :fixed].include? kind
-      raise ArgumentError, "unknown value passed for kind"
+    unless [:warning, :error, :fixed].include?(kind)
+      raise ArgumentError, 'unknown value passed for kind'
     end
 
     [:message, :line, :column, :check].each do |attr|
-      unless problem.has_key? attr
+      unless problem.key?(attr)
         raise ArgumentError, "problem hash must contain #{attr.inspect}"
       end
     end
