@@ -48,7 +48,7 @@ class PuppetLint::OptParser
       opts.on(
         '--error-level LEVEL',
         [:all, :warning, :error],
-        'The level of error to return (warning, error or all).'
+        'The level of error to return (warning, error or all).',
       ) do |el|
         PuppetLint.configuration.error_level = el
       end
@@ -98,6 +98,10 @@ class PuppetLint::OptParser
         PuppetLint.configuration.json = true
       end
 
+      opts.on('--sarif', 'Log output as SARIF') do
+        PuppetLint.configuration.sarif = true
+      end
+
       opts.on('--list-checks', 'List available check names.') do
         PuppetLint.configuration.list_checks = true
       end
