@@ -7,15 +7,10 @@
 PuppetLint.new_check(:'140chars') do
   def check
     manifest_lines.each_with_index do |line, idx|
-      next if line =~ %r{://} || line =~ %r{template\(}
-      next unless line.scan(%r{.}mu).size > 140
+      result = PuppetLint::LineLengthCheck.check(idx + 1, line, 140)
 
-      notify(
-        :warning,
-        :message => 'line has more than 140 characters',
-        :line    => idx + 1,
-        :column  => 140
-      )
+      next if result.nil?
+      notify(*result)
     end
   end
 end
